@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,14 +12,14 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #include "macro.h"
 
 #include <typeinfo>
 
-#include <QRegExp>
+#include <QDebug>
 #include <QStringList>
 
 /**
@@ -52,6 +52,16 @@ Macro::~Macro()
     delete d;
 }
 
+bool Macro::operator==(const Macro &other) const
+{
+    return d->key == other.d->key && d->value == other.d->value;
+}
+
+bool Macro::operator!=(const Macro &other) const
+{
+    return !operator ==(other);
+}
+
 Macro &Macro::operator= (const Macro &other)
 {
     if (this != &other) {
@@ -89,3 +99,8 @@ void Macro::setValue(const Value &value)
 bool Macro::isMacro(const Element &other) {
     return typeid(other) == typeid(Macro);
 }
+
+QDebug operator<<(QDebug dbg, const Macro &macro) {
+    dbg.nospace() << "Macro " << macro.key() << " = " << macro.value();
+    return dbg;
+}
