@@ -416,7 +416,7 @@ bool ReferenceWidget::validate(QWidget **widgetWithIssue, QString &message) cons
         return false;
     }
 
-    static const QRegularExpression validIdRegExp(QStringLiteral("^[a-z][a-z0-9_:.+/$\\\"&-]*$"), QRegularExpression::CaseInsensitiveOption);
+    static const QRegularExpression validIdRegExp(QStringLiteral("^[a-z0-9][a-z0-9_:.+/$\\\"&-]*$"), QRegularExpression::CaseInsensitiveOption);
     const QString id = entryId->text();
     const QRegularExpressionMatch validIdMatch = validIdRegExp.match(id);
     if (!validIdMatch.hasMatch() || validIdMatch.capturedLength() != id.length()) {
@@ -680,10 +680,10 @@ bool FilesWidget::apply(QSharedPointer<Element> element) const
     if (localFileValue.isEmpty()) {
         entry->remove(Entry::ftFile);
         entry->remove(Entry::ftLocalFile);
-    } else if (Preferences::bibliographySystem() == Preferences::BibLaTeX) {
+    } else if (Preferences::instance().bibliographySystem() == Preferences::BibLaTeX) {
         entry->remove(Entry::ftLocalFile);
         entry->insert(Entry::ftFile, localFileValue);
-    } else if (Preferences::bibliographySystem() == Preferences::BibTeX) {
+    } else if (Preferences::instance().bibliographySystem() == Preferences::BibTeX) {
         entry->remove(Entry::ftFile);
         entry->insert(Entry::ftLocalFile, localFileValue);
     }
@@ -1234,8 +1234,16 @@ bool SourceWidget::reset(QSharedPointer<const Element> element)
     const QString exportedText = exporter.toString(element, m_file);
     if (!exportedText.isEmpty()) {
         originalText = exportedText;
-        document->setText(originalText);
-    }
+        /// Limitation of KTextEditor: If editor is read-only, no text can be set
+        /// Therefore, temporarily lift read-only status
+        const bool originalReadWriteStatus = document->isReadWrite();
+        document->setReadWrite(true);
+        const bool settingTextSuccessful = document->setText(originalText);
+        if (!settingTextSuccessful)
+            qCWarning(LOG_KBIBTEX_GUI) << "Could not set BibTeX source code to source editor";
+        document->setReadWrite(originalReadWriteStatus);
+    } else
+        qCWarning(LOG_KBIBTEX_GUI) << "Converting entry to BibTeX source resulting in empty text";
 
     connect(document, &KTextEditor::Document::textChanged, this, &SourceWidget::gotModified);
 
@@ -1252,7 +1260,7 @@ bool SourceWidget::validate(QWidget **widgetWithIssue, QString &message) const
     const QScopedPointer<const File> file(d->importerBibTeX->fromString(text));
     disconnect(d->importerBibTeX, &FileImporterBibTeX::message, this, &SourceWidget::addMessage);
     if (file.isNull() || file->count() != 1) {
-        if (widgetWithIssue != nullptr) *widgetWithIssue = document->views().first(); ///< We create one view initially, so this should never fail
+        if (widgetWithIssue != nullptr) *widgetWithIssue = document->views().at(0); ///< We create one view initially, so this should never fail
         message = i18n("Given source code does not parse as one single BibTeX element.");
         return false;
     }
@@ -1284,7 +1292,7 @@ bool SourceWidget::validate(QWidget **widgetWithIssue, QString &message) const
     }
 
     if (!result && widgetWithIssue != nullptr)
-        *widgetWithIssue = document->views().first(); ///< We create one view initially, so this should never fail
+        *widgetWithIssue = document->views().at(0); ///< We create one view initially, so this should never fail
 
     if (message.isEmpty() && d->messages->count() == 0)
         d->addMessage(FileImporter::SeverityInfo, i18n("No issues detected"));
