@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,7 +12,7 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #include "fieldlineedit.h"
@@ -26,17 +26,20 @@
 #include <QDir>
 #include <QDragEnterEvent>
 #include <QDropEvent>
+#include <QPushButton>
+#include <QFontDatabase>
+#include <QUrl>
+#include <QMimeDatabase>
+#include <QMimeType>
+#include <QMimeData>
+#include <QRegularExpression>
 
-#include <KMimeType>
 #include <KRun>
-#include <KDebug>
 #include <KMessageBox>
-#include <KGlobalSettings>
-#include <KLocale>
-#include <KUrl>
-#include <KPushButton>
+#include <KLocalizedString>
 #include <KSharedConfig>
 #include <KConfigGroup>
+#include <kio_version.h>
 
 #include "fileinfo.h"
 #include "file.h"
@@ -47,6 +50,7 @@
 #include "bibtexfields.h"
 #include "encoderlatex.h"
 #include "preferences.h"
+#include "logging_gui.h"
 
 class FieldLineEdit::FieldLineEditPrivate
 {
@@ -56,7 +60,7 @@ private:
     KBibTeX::TypeFlag preferredTypeFlag;
     KBibTeX::TypeFlags typeFlags;
     QSignalMapper *menuTypesSignalMapper;
-    KPushButton *buttonOpenUrl;
+    QPushButton *buttonOpenUrl;
 
     KSharedConfigPtr config;
     const QString configGroupNameGeneral;
@@ -65,24 +69,24 @@ private:
 public:
     QMenu *menuTypes;
     KBibTeX::TypeFlag typeFlag;
-    KUrl urlToOpen;
+    QUrl urlToOpen;
     const File *file;
     QString fieldKey;
 
     FieldLineEditPrivate(KBibTeX::TypeFlag ptf, KBibTeX::TypeFlags tf, FieldLineEdit *p)
-            : parent(p), preferredTypeFlag(ptf), typeFlags(tf), config(KSharedConfig::openConfig(QLatin1String("kbibtexrc"))), configGroupNameGeneral(QLatin1String("General")), file(NULL) {
+            : parent(p), preferredTypeFlag(ptf), typeFlags(tf), config(KSharedConfig::openConfig(QStringLiteral("kbibtexrc"))), configGroupNameGeneral(QStringLiteral("General")), file(nullptr) {
         menuTypes = new QMenu(parent);
         menuTypesSignalMapper = new QSignalMapper(parent);
         setupMenu();
-        connect(menuTypesSignalMapper, SIGNAL(mapped(int)), parent, SLOT(slotTypeChanged(int)));
+        connect(menuTypesSignalMapper, static_cast<void(QSignalMapper::*)(int)>(&QSignalMapper::mapped), parent, &FieldLineEdit::slotTypeChanged);
 
-        buttonOpenUrl = new KPushButton(KIcon("document-open-remote"), "", parent);
+        buttonOpenUrl = new QPushButton(QIcon::fromTheme(QStringLiteral("document-open-remote")), QString(), parent);
         buttonOpenUrl->setVisible(false);
         buttonOpenUrl->setProperty("isConst", true);
         parent->appendWidget(buttonOpenUrl);
-        connect(buttonOpenUrl, SIGNAL(clicked()), parent, SLOT(slotOpenUrl()));
+        connect(buttonOpenUrl, &QPushButton::clicked, parent, &FieldLineEdit::slotOpenUrl);
 
-        connect(p, SIGNAL(textChanged(QString)), p, SLOT(slotTextChanged(QString)));
+        connect(p, &FieldLineEdit::textChanged, p, &FieldLineEdit::slotTextChanged);
 
         Value value;
         typeFlag = determineTypeFlag(value, preferredTypeFlag, typeFlags);
@@ -92,12 +96,6 @@ public:
         personNameFormatting = configGroup.readEntry(Preferences::keyPersonNameFormatting, Preferences::defaultPersonNameFormatting);
     }
 
-    ~FieldLineEditPrivate() {
-        delete menuTypes;
-        delete menuTypesSignalMapper;
-        delete buttonOpenUrl;
-    }
-
     bool reset(const Value &value) {
         bool result = false;
         QString text;
@@ -107,7 +105,7 @@ public:
         if (!value.isEmpty()) {
             if (typeFlag == KBibTeX::tfSource) {
                 /// simple case: field's value is to be shown as BibTeX code, including surrounding curly braces
-                FileExporterBibTeX exporter;
+                FileExporterBibTeX exporter(parent);
                 text = exporter.valueToBibTeX(value);
                 result = true;
             } else {
@@ -140,7 +138,7 @@ public:
                                     text = verbatimText->text();
                                     result = true;
                                 } else
-                                    kWarning() << "Could not reset: " << typeFlag << "(" << (typeFlag == KBibTeX::tfSource ? "Source" : (typeFlag == KBibTeX::tfReference ? "Reference" : (typeFlag == KBibTeX::tfPerson ? "Person" : (typeFlag == KBibTeX::tfPlainText ? "PlainText" : (typeFlag == KBibTeX::tfKeyword ? "Keyword" : (typeFlag == KBibTeX::tfVerbatim ? "Verbatim" : "???")))))) << ") " << (typeFlags.testFlag(KBibTeX::tfPerson) ? "Person" : "") << (typeFlags.testFlag(KBibTeX::tfPlainText) ? "PlainText" : "") << (typeFlags.testFlag(KBibTeX::tfReference) ? "Reference" : "") << (typeFlags.testFlag(KBibTeX::tfVerbatim) ? "Verbatim" : "") << " " << typeid((void)*first).name() << " : " << PlainTextValue::text(value);
+                                    qCWarning(LOG_KBIBTEX_GUI) << "Could not reset: " << typeFlag << "(" << (typeFlag == KBibTeX::tfSource ? "Source" : (typeFlag == KBibTeX::tfReference ? "Reference" : (typeFlag == KBibTeX::tfPerson ? "Person" : (typeFlag == KBibTeX::tfPlainText ? "PlainText" : (typeFlag == KBibTeX::tfKeyword ? "Keyword" : (typeFlag == KBibTeX::tfVerbatim ? "Verbatim" : "???")))))) << ") " << (typeFlags.testFlag(KBibTeX::tfPerson) ? "Person" : "") << (typeFlags.testFlag(KBibTeX::tfPlainText) ? "PlainText" : "") << (typeFlags.testFlag(KBibTeX::tfReference) ? "Reference" : "") << (typeFlags.testFlag(KBibTeX::tfVerbatim) ? "Verbatim" : "") << " " << typeid((void)*first).name() << " : " << PlainTextValue::text(value);
                             }
                         }
                     }
@@ -159,16 +157,18 @@ public:
         /// Remove unnecessary white space from input
         /// Exception: source and verbatim content is kept unmodified
         const QString text = typeFlag == KBibTeX::tfSource || typeFlag == KBibTeX::tfVerbatim ? parent->text() : parent->text().simplified();
+        if (text.isEmpty())
+            return true;
 
-        EncoderLaTeX *encoder = EncoderLaTeX::instance();
-        const QString encodedText = encoder->decode(text);
-
+        const EncoderLaTeX &encoder = EncoderLaTeX::instance();
+        const QString encodedText = encoder.decode(text);
+        static const QRegularExpression invalidCharsForReferenceRegExp(QStringLiteral("[^-_:/a-zA-Z0-9]"));
         if (encodedText.isEmpty())
             return true;
         else if (typeFlag == KBibTeX::tfPlainText) {
             value.append(QSharedPointer<PlainText>(new PlainText(encodedText)));
             return true;
-        } else if (typeFlag == KBibTeX::tfReference && !encodedText.contains(QRegExp("[^-_:/a-zA-Z0-9]"))) {
+        } else if (typeFlag == KBibTeX::tfReference && !encodedText.contains(invalidCharsForReferenceRegExp)) {
             value.append(QSharedPointer<MacroKey>(new MacroKey(encodedText)));
             return true;
         } else if (typeFlag == KBibTeX::tfPerson) {
@@ -177,25 +177,24 @@ public:
                 value.append(person);
             return true;
         } else if (typeFlag == KBibTeX::tfKeyword) {
-            QList<QSharedPointer<Keyword> > keywords = FileImporterBibTeX::splitKeywords(encodedText);
-            for (QList<QSharedPointer<Keyword> >::ConstIterator it = keywords.constBegin(); it != keywords.constEnd(); ++it)
-                value.append(*it);
+            const QList<QSharedPointer<Keyword> > keywords = FileImporterBibTeX::splitKeywords(encodedText);
+            for (const auto &keyword : keywords)
+                value.append(keyword);
             return true;
         } else if (typeFlag == KBibTeX::tfSource) {
-            QString key = typeFlags.testFlag(KBibTeX::tfPerson) ? "author" : "title";
-            FileImporterBibTeX importer;
-            QString fakeBibTeXFile = QString(QLatin1String("@article{dummy, %1=%2}")).arg(key, encodedText);
+            const QString key = typeFlags.testFlag(KBibTeX::tfPerson) ? QStringLiteral("author") : QStringLiteral("title");
+            FileImporterBibTeX importer(parent);
+            const QString fakeBibTeXFile = QString(QStringLiteral("@article{dummy, %1=%2}")).arg(key, encodedText);
 
-            File *file = importer.fromString(fakeBibTeXFile);
-            QSharedPointer<Entry> entry;
-            if (file != NULL) {
-                if (!file->isEmpty() && !(entry = (file->first().dynamicCast<Entry>())).isNull())
+            const QScopedPointer<const File> file(importer.fromString(fakeBibTeXFile));
+            if (!file.isNull() && file->count() == 1) {
+                QSharedPointer<Entry> entry = file->first().dynamicCast<Entry>();
+                if (!entry.isNull()) {
                     value = entry->value(key);
-                delete file;
+                    return !value.isEmpty();
+                } else
+                    qCWarning(LOG_KBIBTEX_GUI) << "Parsing " << fakeBibTeXFile << " did not result in valid entry";
             }
-            if (entry.isNull())
-                kWarning() << "Parsing " << fakeBibTeXFile << " did not result in valid entry";
-            return !value.isEmpty();
         } else if (typeFlag == KBibTeX::tfVerbatim) {
             value.append(QSharedPointer<VerbatimText>(new VerbatimText(text)));
             return true;
@@ -204,6 +203,50 @@ public:
         return false;
     }
 
+    bool validate(QWidget **widgetWithIssue, QString &message) const {
+        message.clear();
+
+        /// Remove unnecessary white space from input
+        /// Exception: source and verbatim content is kept unmodified
+        const QString text = typeFlag == KBibTeX::tfSource || typeFlag == KBibTeX::tfVerbatim ? parent->text() : parent->text().simplified();
+        if (text.isEmpty())
+            return true;
+
+        const EncoderLaTeX &encoder = EncoderLaTeX::instance();
+        const QString encodedText = encoder.decode(text);
+        if (encodedText.isEmpty())
+            return true;
+
+        bool result = false;
+        if (typeFlag == KBibTeX::tfPlainText || typeFlag == KBibTeX::tfPerson || typeFlag == KBibTeX::tfKeyword) {
+            result = KBibTeX::validateCurlyBracketContext(text) == 0;
+            if (!result) message = i18n("Opening and closing curly brackets do not match.");
+        } else if (typeFlag == KBibTeX::tfReference) {
+            static const QRegularExpression validReferenceRegExp(QStringLiteral("^[-_:/a-zA-Z0-9]+$"));
+            const QRegularExpressionMatch validReferenceMatch = validReferenceRegExp.match(text);
+            result = validReferenceMatch.hasMatch() && validReferenceMatch.captured() == text;
+            if (!result) message = i18n("Reference contains characters outside of the allowed set.");
+        } else if (typeFlag == KBibTeX::tfSource) {
+            const QString key = typeFlags.testFlag(KBibTeX::tfPerson) ? QStringLiteral("author") : QStringLiteral("title");
+            FileImporterBibTeX importer(parent);
+            const QString fakeBibTeXFile = QString(QStringLiteral("@article{dummy, %1=%2}")).arg(key, encodedText);
+
+            const QScopedPointer<const File> file(importer.fromString(fakeBibTeXFile));
+            if (file.isNull() || file->count() != 1) return false;
+            QSharedPointer<Entry> entry = file->first().dynamicCast<Entry>();
+            result = !entry.isNull() && entry->count() == 1;
+            if (!result) message = i18n("Source code could not be parsed correctly.");
+        } else if (typeFlag == KBibTeX::tfVerbatim) {
+            result = KBibTeX::validateCurlyBracketContext(text) == 0;
+            if (!result) message = i18n("Opening and closing curly brackets do not match.");
+        }
+
+        if (!result && widgetWithIssue != nullptr)
+            *widgetWithIssue = parent;
+
+        return result;
+    }
+
     KBibTeX::TypeFlag determineTypeFlag(const Value &value, KBibTeX::TypeFlag preferredTypeFlag, KBibTeX::TypeFlags availableTypeFlags) {
         KBibTeX::TypeFlag result = KBibTeX::tfSource;
         if (availableTypeFlags.testFlag(preferredTypeFlag) && typeFlagSupported(value, preferredTypeFlag))
@@ -211,7 +254,7 @@ public:
         else if (value.count() == 1) {
             int p = 1;
             for (int i = 1; i < 8; ++i, p <<= 1) {
-                KBibTeX::TypeFlag flag = (KBibTeX::TypeFlag)p;
+                const KBibTeX::TypeFlag flag = static_cast<KBibTeX::TypeFlag>(p);
                 if (availableTypeFlags.testFlag(flag) && typeFlagSupported(value, flag)) {
                     result = flag; break;
                 }
@@ -271,20 +314,20 @@ public:
         }
     }
 
-    KIcon iconForTypeFlag(KBibTeX::TypeFlag typeFlag) {
+    QIcon iconForTypeFlag(KBibTeX::TypeFlag typeFlag) {
         switch (typeFlag) {
-        case KBibTeX::tfPlainText: return KIcon("draw-text");
-        case KBibTeX::tfReference: return KIcon("emblem-symbolic-link");
-        case KBibTeX::tfPerson: return KIcon("user-identity");
-        case KBibTeX::tfKeyword: return KIcon("edit-find");
-        case KBibTeX::tfSource: return KIcon("code-context");
-        case KBibTeX::tfVerbatim: return KIcon("preferences-desktop-keyboard");
-        default: return KIcon();
+        case KBibTeX::tfPlainText: return QIcon::fromTheme(QStringLiteral("draw-text"));
+        case KBibTeX::tfReference: return QIcon::fromTheme(QStringLiteral("emblem-symbolic-link"));
+        case KBibTeX::tfPerson: return QIcon::fromTheme(QStringLiteral("user-identity"));
+        case KBibTeX::tfKeyword: return QIcon::fromTheme(QStringLiteral("edit-find"));
+        case KBibTeX::tfSource: return QIcon::fromTheme(QStringLiteral("code-context"));
+        case KBibTeX::tfVerbatim: return QIcon::fromTheme(QStringLiteral("preferences-desktop-keyboard"));
+        default: return QIcon();
         };
     }
 
     void updateGUI(KBibTeX::TypeFlag typeFlag) {
-        parent->setFont(KGlobalSettings::generalFont());
+        parent->setFont(QFontDatabase::systemFont(QFontDatabase::GeneralFont));
         parent->setIcon(iconForTypeFlag(typeFlag));
         switch (typeFlag) {
         case KBibTeX::tfPlainText: parent->setButtonToolTip(i18n("Plain Text")); break;
@@ -293,20 +336,24 @@ public:
         case KBibTeX::tfKeyword: parent->setButtonToolTip(i18n("Keyword")); break;
         case KBibTeX::tfSource:
             parent->setButtonToolTip(i18n("Source Code"));
-            parent->setFont(KGlobalSettings::fixedFont());
+            parent->setFont(QFontDatabase::systemFont(QFontDatabase::FixedFont));
             break;
         case KBibTeX::tfVerbatim: parent->setButtonToolTip(i18n("Verbatim Text")); break;
-        default: parent->setButtonToolTip(""); break;
+        default: parent->setButtonToolTip(QString()); break;
         };
     }
 
     void openUrl() {
         if (urlToOpen.isValid()) {
             /// Guess mime type for url to open
-            KMimeType::Ptr mimeType = FileInfo::mimeTypeForUrl(urlToOpen);
-            const QString mimeTypeName = mimeType->name();
+            QMimeType mimeType = FileInfo::mimeTypeForUrl(urlToOpen);
+            const QString mimeTypeName = mimeType.name();
             /// Ask KDE subsystem to open url in viewer matching mime type
+#if KIO_VERSION < 0x051f00 // < 5.31.0
             KRun::runUrl(urlToOpen, mimeTypeName, parent, false, false);
+#else // KIO_VERSION < 0x051f00 // >= 5.31.0
+            KRun::runUrl(urlToOpen, mimeTypeName, parent, KRun::RunFlags());
+#endif // KIO_VERSION < 0x051f00
         }
     }
 
@@ -315,13 +362,13 @@ public:
         if (destType == KBibTeX::tfSource) return true; /// simple case
 
         bool result = true;
-        EncoderLaTeX *enc = EncoderLaTeX::instance();
+        const EncoderLaTeX &encoder = EncoderLaTeX::instance();
         QString rawText;
         const QSharedPointer<ValueItem> first = value.first();
 
         const QSharedPointer<PlainText> plainText = first.dynamicCast<PlainText>();
         if (!plainText.isNull())
-            rawText = enc->encode(plainText->text());
+            rawText = encoder.encode(plainText->text(), Encoder::TargetEncodingASCII);
         else {
             const QSharedPointer<VerbatimText> verbatimText = first.dynamicCast<VerbatimText>();
             if (!verbatimText.isNull())
@@ -333,11 +380,11 @@ public:
                 else {
                     const QSharedPointer<Person> person = first.dynamicCast<Person>();
                     if (!person.isNull())
-                        rawText = enc->encode(QString(QLatin1String("%1 %2")).arg(person->firstName(), person->lastName())); // FIXME proper name conversion
+                        rawText = encoder.encode(QString(QStringLiteral("%1 %2")).arg(person->firstName(), person->lastName()), Encoder::TargetEncodingASCII); // FIXME proper name conversion
                     else {
                         const QSharedPointer<Keyword> keyword = first.dynamicCast<Keyword>();
                         if (!keyword.isNull())
-                            rawText = enc->encode(keyword->text());
+                            rawText = encoder.encode(keyword->text(), Encoder::TargetEncodingASCII);
                         else {
                             // TODO case missed?
                             result = false;
@@ -350,7 +397,7 @@ public:
         switch (destType) {
         case KBibTeX::tfPlainText:
             value.clear();
-            value.append(QSharedPointer<PlainText>(new PlainText(enc->decode(rawText))));
+            value.append(QSharedPointer<PlainText>(new PlainText(encoder.decode(rawText))));
             break;
         case KBibTeX::tfVerbatim:
             value.clear();
@@ -358,7 +405,7 @@ public:
             break;
         case KBibTeX::tfPerson:
             value.clear();
-            value.append(QSharedPointer<Person>(FileImporterBibTeX::splitName(enc->decode(rawText))));
+            value.append(QSharedPointer<Person>(FileImporterBibTeX::splitName(encoder.decode(rawText))));
             break;
         case KBibTeX::tfReference: {
             MacroKey *macroKey = new MacroKey(rawText);
@@ -373,7 +420,7 @@ public:
         break;
         case KBibTeX::tfKeyword:
             value.clear();
-            value.append(QSharedPointer<Keyword>(new Keyword(enc->decode(rawText))));
+            value.append(QSharedPointer<Keyword>(new Keyword(encoder.decode(rawText))));
             break;
         default: {
             // TODO
@@ -385,16 +432,17 @@ public:
     }
 
     void updateURL(const QString &text) {
-        QList<KUrl> urls;
-        FileInfo::urlsInText(text, FileInfo::TestExistenceYes, file != NULL && file->property(File::Url).toUrl().isValid() ? KUrl(file->property(File::Url).toUrl()).directory() : QString(), urls);
-        if (!urls.isEmpty() && urls.first().isValid())
-            urlToOpen = urls.first();
+        QSet<QUrl> urls;
+        FileInfo::urlsInText(text, FileInfo::TestExistenceYes, file != nullptr && file->property(File::Url).toUrl().isValid() ? QUrl(file->property(File::Url).toUrl()).path() : QString(), urls);
+        QSet<QUrl>::ConstIterator urlsIt = urls.constBegin();
+        if (urlsIt != urls.constEnd() && (*urlsIt).isValid())
+            urlToOpen = (*urlsIt);
         else
-            urlToOpen = KUrl();
+            urlToOpen = QUrl();
 
         /// set special "open URL" button visible if URL (or file or DOI) found
         buttonOpenUrl->setVisible(urlToOpen.isValid());
-        buttonOpenUrl->setToolTip(i18n("Open '%1'", urlToOpen.pathOrUrl()));
+        buttonOpenUrl->setToolTip(i18n("Open '%1'", urlToOpen.url(QUrl::PreferLocalFile)));
     }
 
     void textChanged(const QString &text) {
@@ -406,7 +454,7 @@ FieldLineEdit::FieldLineEdit(KBibTeX::TypeFlag preferredTypeFlag, KBibTeX::TypeF
         : MenuLineEdit(isMultiLine, parent), d(new FieldLineEdit::FieldLineEditPrivate(preferredTypeFlag, typeFlags, this))
 {
     setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
-    setObjectName(QLatin1String("FieldLineEdit"));
+    setObjectName(QStringLiteral("FieldLineEdit"));
     setMenu(d->menuTypes);
     setChildAcceptDrops(false);
     setAcceptDrops(true);
@@ -427,6 +475,11 @@ bool FieldLineEdit::reset(const Value &value)
     return d->reset(value);
 }
 
+bool FieldLineEdit::validate(QWidget **widgetWithIssue, QString &message) const
+{
+    return d->validate(widgetWithIssue, message);
+}
+
 void FieldLineEdit::setReadOnly(bool isReadOnly)
 {
     MenuLineEdit::setReadOnly(isReadOnly);
@@ -434,7 +487,7 @@ void FieldLineEdit::setReadOnly(bool isReadOnly)
 
 void FieldLineEdit::slotTypeChanged(int newTypeFlagInt)
 {
-    KBibTeX::TypeFlag newTypeFlag = (KBibTeX::TypeFlag)newTypeFlagInt;
+    const KBibTeX::TypeFlag newTypeFlag = static_cast<KBibTeX::TypeFlag>(newTypeFlagInt);
 
     Value value;
     d->apply(value);
@@ -473,7 +526,7 @@ void FieldLineEdit::slotTextChanged(const QString &text)
 
 void FieldLineEdit::dragEnterEvent(QDragEnterEvent *event)
 {
-    if (event->mimeData()->hasFormat("text/plain") || event->mimeData()->hasFormat("text/x-bibtex"))
+    if (event->mimeData()->hasFormat(QStringLiteral("text/plain")) || event->mimeData()->hasFormat(QStringLiteral("text/x-bibtex")))
         event->acceptProposedAction();
 }
 
@@ -482,27 +535,27 @@ void FieldLineEdit::dropEvent(QDropEvent *event)
     const QString clipboardText = event->mimeData()->text();
     if (clipboardText.isEmpty()) return;
 
-    const File *file = NULL;
-    if (!d->fieldKey.isEmpty() && clipboardText.startsWith(QLatin1String("@"))) {
-        FileImporterBibTeX importer;
-        file = importer.fromString(clipboardText);
-        const QSharedPointer<Entry> entry = (file != NULL && file->count() == 1) ? file->first().dynamicCast<Entry>() : QSharedPointer<Entry>();
+    bool success = false;
+    if (!d->fieldKey.isEmpty() && clipboardText.startsWith(QStringLiteral("@"))) {
+        FileImporterBibTeX importer(this);
+        QScopedPointer<File> file(importer.fromString(clipboardText));
+        const QSharedPointer<Entry> entry = (!file.isNull() && file->count() == 1) ? file->first().dynamicCast<Entry>() : QSharedPointer<Entry>();
         if (!entry.isNull() && d->fieldKey == Entry::ftCrossRef) {
             /// handle drop on crossref line differently (use dropped entry's id)
             Value v;
             v.append(QSharedPointer<VerbatimText>(new VerbatimText(entry->id())));
             reset(v);
             emit textChanged(entry->id());
-            return;
+            success = true;
         } else if (!entry.isNull() && entry->contains(d->fieldKey)) {
             /// case for "normal" fields like for journal, pages, ...
             reset(entry->value(d->fieldKey));
             emit textChanged(text());
-            return;
+            success = true;
         }
     }
 
-    if (file == NULL || file->count() == 0) {
+    if (!success) {
         /// fall-back case: just copy whole text into edit widget
         setText(clipboardText);
         emit textChanged(clipboardText);
