@@ -171,16 +171,17 @@ Element *FileImporterBibTeX::nextElement()
     Token token = nextToken();
 
     if (token == tAt) {
-        QString elementType = readSimpleString();
+        const QString elementType = readSimpleString();
+        const QString elementTypeLower = elementType.toLower();
 
-        if (elementType.toLower() == QStringLiteral("comment")) {
+        if (elementTypeLower == QStringLiteral("comment")) {
             ++m_statistics.countCommentCommand;
             return readCommentElement();
-        } else if (elementType.toLower() == QStringLiteral("string"))
+        } else if (elementTypeLower == QStringLiteral("string"))
             return readMacroElement();
-        else if (elementType.toLower() == QStringLiteral("preamble"))
+        else if (elementTypeLower == QStringLiteral("preamble"))
             return readPreambleElement();
-        else if (elementType.toLower() == QStringLiteral("import")) {
+        else if (elementTypeLower == QStringLiteral("import")) {
             qCDebug(LOG_KBIBTEX_IO) << "Skipping potential HTML/JavaScript @import statement near line" << m_lineNo;
             emit message(SeverityInfo, QString(QStringLiteral("Skipping potential HTML/JavaScript @import statement near line %1")).arg(m_lineNo));
             return nullptr;
@@ -280,7 +281,7 @@ Macro *FileImporterBibTeX::readMacroElement()
         while (m_knownElementIds.contains(newKey))
             newKey = newIdPattern.arg(key).arg(++idx);
         qCDebug(LOG_KBIBTEX_IO) << "Duplicate macro key" << key << ", using replacement key" << newKey;
-        emit message(SeverityWarning, QString(QStringLiteral("Duplicate macro key '%1', using replacement key '%2'")).arg(key).arg(newKey));
+        emit message(SeverityWarning, QString(QStringLiteral("Duplicate macro key '%1', using replacement key '%2'")).arg(key, newKey));
         key = newKey;
     }
     m_knownElementIds.insert(key);
@@ -360,7 +361,7 @@ Entry *FileImporterBibTeX::readEntryElement(const QString &typeString)
         token = nextToken();
     }
 
-    QString id = readSimpleString(QStringLiteral(",}")).trimmed();
+    QString id = readSimpleString(QStringLiteral(",}"), true).trimmed();
     if (id.isEmpty()) {
         if (m_nextChar == QLatin1Char(',') || m_nextChar == QLatin1Char('}')) {
             /// Cope with empty ids,
@@ -372,12 +373,20 @@ Entry *FileImporterBibTeX::readEntryElement(const QString &typeString)
             emit message(SeverityError, QString(QStringLiteral("Error in parsing preambentryle near line %1: Could not read entry id")).arg(m_lineNo));
             return nullptr;
         }
-    } else if (!EncoderLaTeX::containsOnlyAscii(id)) {
-        /// Try to avoid non-ascii characters in ids
-        const QString newId = EncoderLaTeX::instance().convertToPlainAscii(id);
-        qCWarning(LOG_KBIBTEX_IO) << "Entry id" << id << "near line" << m_lineNo << "contains non-ASCII characters, converted to" << newId;
-        emit message(SeverityWarning, QString(QStringLiteral("Entry id '%1' near line %2 contains non-ASCII characters, converted to '%3'")).arg(id).arg(m_lineNo).arg(newId));
-        id = newId;
+    } else {
+        if (id.contains(QStringLiteral("\\")) || id.contains(QStringLiteral("{"))) {
+            const QString newId = EncoderLaTeX::instance().decode(id);
+            qCWarning(LOG_KBIBTEX_IO) << "Entry id" << id << "near line" << m_lineNo << "contains backslashes or curly brackets, converted to" << newId;
+            emit message(SeverityWarning, QString(QStringLiteral("Entry id '%1' near line %2 contains backslashes or curly brackets, converted to '%3'")).arg(id).arg(m_lineNo).arg(newId));
+            id = newId;
+        }
+        if (!EncoderLaTeX::containsOnlyAscii(id)) {
+            /// Try to avoid non-ascii characters in ids
+            const QString newId = EncoderLaTeX::instance().convertToPlainAscii(id);
+            qCWarning(LOG_KBIBTEX_IO) << "Entry id" << id << "near line" << m_lineNo << "contains non-ASCII characters, converted to" << newId;
+            emit message(SeverityWarning, QString(QStringLiteral("Entry id '%1' near line %2 contains non-ASCII characters, converted to '%3'")).arg(id).arg(m_lineNo).arg(newId));
+            id = newId;
+        }
     }
     static const QVector<QChar> invalidIdCharacters = {QLatin1Char('{'), QLatin1Char('}'), QLatin1Char(',')};
     for (const QChar &invalidIdCharacter : invalidIdCharacters)
@@ -455,7 +464,7 @@ Entry *FileImporterBibTeX::readEntryElement(const QString &typeString)
         token = nextToken();
         if (token != tAssign) {
             qCWarning(LOG_KBIBTEX_IO) << "Error in parsing entry" << id << ", field name" << keyName << "near line" << m_lineNo  << "(" << m_prevLine << endl << m_currentLine << "): Assign symbol '=' expected after field name";
-            emit message(SeverityError, QString(QStringLiteral("Error in parsing entry '%1', field name '%2' near line %3: Assign symbol '=' expected after field name")).arg(id).arg(keyName).arg(m_lineNo));
+            emit message(SeverityError, QString(QStringLiteral("Error in parsing entry '%1', field name '%2' near line %3: Assign symbol '=' expected after field name")).arg(id, keyName).arg(m_lineNo));
             delete entry;
             return nullptr;
         }
@@ -482,7 +491,7 @@ Entry *FileImporterBibTeX::readEntryElement(const QString &typeString)
                     appendix = QString::number(i);
                 }
                 qCDebug(LOG_KBIBTEX_IO) << "Entry" << id << "already contains a key" << keyName << "near line" << m_lineNo << "(" << m_prevLine << endl << m_currentLine << "), using" << (keyName + appendix);
-                emit message(SeverityWarning, QString(QStringLiteral("Entry '%1' already contains a key '%2' near line %3, using '%4'")).arg(id).arg(keyName).arg(m_lineNo).arg(keyName + appendix));
+                emit message(SeverityWarning, QString(QStringLiteral("Entry '%1' already contains a key '%2' near line %4, using '%3'")).arg(id, keyName, keyName + appendix).arg(m_lineNo));
                 keyName += appendix;
             }
         }
@@ -490,7 +499,7 @@ Entry *FileImporterBibTeX::readEntryElement(const QString &typeString)
         token = readValue(value, keyName);
         if (token != tBracketClose && token != tComma) {
             qCWarning(LOG_KBIBTEX_IO) << "Failed to read value in entry" << id << ", field name" << keyName << "near line" << m_lineNo  << "(" << m_prevLine << endl << m_currentLine << ")";
-            emit message(SeverityError, QString(QStringLiteral("Failed to read value in entry '%1', field name '%2' near line %3")).arg(id).arg(keyName).arg(m_lineNo));
+            emit message(SeverityError, QString(QStringLiteral("Failed to read value in entry '%1', field name '%2' near line %3")).arg(id, keyName).arg(m_lineNo));
             delete entry;
             return nullptr;
         }
@@ -573,7 +582,7 @@ QString FileImporterBibTeX::readString(bool &isStringKey)
     }
 }
 
-QString FileImporterBibTeX::readSimpleString(const QString &until)
+QString FileImporterBibTeX::readSimpleString(const QString &until, const bool readNestedCurlyBrackets)
 {
     static const QString extraAlphaNumChars = QString(QStringLiteral("?'`-_:.+/$\\\"&"));
 
@@ -584,7 +593,22 @@ QString FileImporterBibTeX::readSimpleString(const QString &until)
         return QString::null;
     }
 
+    QChar prevChar = QChar(0x00);
     while (!m_nextChar.isNull()) {
+        if (readNestedCurlyBrackets && m_nextChar == QLatin1Char('{') && prevChar != QLatin1Char('\\')) {
+            int depth = 1;
+            while (depth > 0) {
+                result.append(m_nextChar);
+                prevChar = m_nextChar;
+                if (!readChar()) return result;
+                if (m_nextChar == QLatin1Char('{') && prevChar != QLatin1Char('\\')) ++depth;
+                else if (m_nextChar == QLatin1Char('}') && prevChar != QLatin1Char('\\')) --depth;
+            }
+            result.append(m_nextChar);
+            prevChar = m_nextChar;
+            if (!readChar()) return result;
+        }
+
         const ushort nextCharUnicode = m_nextChar.unicode();
         if (!until.isEmpty()) {
             /// Variable "until" has user-defined value
@@ -600,6 +624,7 @@ QString FileImporterBibTeX::readSimpleString(const QString &until)
             result.append(m_nextChar);
         } else
             break;
+        prevChar = m_nextChar;
         if (!readChar()) break;
     }
     return result;
@@ -607,7 +632,7 @@ QString FileImporterBibTeX::readSimpleString(const QString &until)
 
 QString FileImporterBibTeX::readQuotedString()
 {
-    QString result(QStringLiteral(""));
+    QString result(0, QChar()); ///< Construct an empty but non-null string
 
     Q_ASSERT_X(m_nextChar == QLatin1Char('"'), "QString FileImporterBibTeX::readQuotedString()", "m_nextChar is not '\"'");
 
@@ -633,7 +658,7 @@ QString FileImporterBibTeX::readQuotedString()
 QString FileImporterBibTeX::readBracketString()
 {
     static const QChar backslash = QLatin1Char('\\');
-    QString result(QStringLiteral(""));
+    QString result(0, QChar()); ///< Construct an empty but non-null string
     const QChar openingBracket = m_nextChar;
     const QChar closingBracket = openingBracket == QLatin1Char('{') ? QLatin1Char('}') : (openingBracket == QLatin1Char('(') ? QLatin1Char(')') : QChar());
     Q_ASSERT_X(!closingBracket.isNull(), "QString FileImporterBibTeX::readBracketString()", "openingBracket==m_nextChar is neither '{' nor '('");
