@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2017 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,7 +12,7 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #include "collection.h"
@@ -24,12 +24,11 @@
 #include <QXmlStreamReader>
 #include <QTimer>
 
-#include <KDebug>
-#include <KLocale>
+#include <KLocalizedString>
 
 #include "api.h"
-
 #include "internalnetworkaccessmanager.h"
+#include "logging_networking.h"
 
 using namespace Zotero;
 
@@ -42,7 +41,6 @@ public:
     QSharedPointer<Zotero::API> api;
 
     static const QString top;
-    KUrl queuedRequestZoteroUrl;
 
     Private(QSharedPointer<Zotero::API> a, Zotero::Collection *parent)
             : p(parent), api(a) {
@@ -58,27 +56,28 @@ public:
     QHash<QString, QString> collectionToParent;
     QHash<QString, QVector<QString> > collectionToChildren;
 
-    QNetworkReply *requestZoteroUrl(const KUrl &url) {
+    QNetworkReply *requestZoteroUrl(const QUrl &url) {
         busy = true;
-        KUrl internalUrl = url;
-        api->addKeyToUrl(internalUrl);
+        QUrl internalUrl = url;
         api->addLimitToUrl(internalUrl);
         QNetworkRequest request = api->request(internalUrl);
-        QNetworkReply *reply = InternalNetworkAccessManager::self()->get(request);
-        connect(reply, SIGNAL(finished()), p, SLOT(finishedFetchingCollection()));
+        QNetworkReply *reply = InternalNetworkAccessManager::instance().get(request);
+        connect(reply, &QNetworkReply::finished, p, &Zotero::Collection::finishedFetchingCollection);
         return reply;
     }
 
     void runNextInDownloadQueue() {
         if (!downloadQueue.isEmpty()) {
             const QString head = downloadQueue.dequeue();
-            KUrl url = api->baseUrl();
-            url.addPath(QString(QLatin1String("/collections/%1/collections")).arg(head));
-            if (api->inBackoffMode() && queuedRequestZoteroUrl.isEmpty()) {
+            QUrl url = api->baseUrl();
+            url = url.adjusted(QUrl::StripTrailingSlash);
+            url.setPath(url.path() + QString(QStringLiteral("/collections/%1/collections")).arg(head));
+            if (api->inBackoffMode())
                 /// If Zotero asked to 'back off', wait until this period is over before issuing the next request
-                queuedRequestZoteroUrl = url;
-                QTimer::singleShot((api->backoffSecondsLeft() + 1) * 1000, p, SLOT(singleShotRequestZoteroUrl()));
-            } else
+                QTimer::singleShot((api->backoffSecondsLeft() + 1) * 1000, p, [ = ]() {
+                    requestZoteroUrl(url);
+                });
+            else
                 requestZoteroUrl(url);
         } else {
             initialized = true;
@@ -87,20 +86,22 @@ public:
     }
 };
 
-const QString Zotero::Collection::Private::top = QLatin1String("top");
+const QString Zotero::Collection::Private::top = QStringLiteral("top");
 
 Collection::Collection(QSharedPointer<Zotero::API> api, QObject *parent)
         : QObject(parent), d(new Zotero::Collection::Private(api, this))
 {
     d->collectionToLabel[Private::top] = i18n("Library");
 
-    KUrl url = api->baseUrl();
-    url.addPath(QLatin1String("/collections/top"));
-    if (api->inBackoffMode() && d->queuedRequestZoteroUrl.isEmpty()) {
+    QUrl url = api->baseUrl();
+    url = url.adjusted(QUrl::StripTrailingSlash);
+    url.setPath(url.path() + QStringLiteral("/collections/top"));
+    if (api->inBackoffMode())
         /// If Zotero asked to 'back off', wait until this period is over before issuing the next request
-        d->queuedRequestZoteroUrl = url;
-        QTimer::singleShot((api->backoffSecondsLeft() + 1) * 1000, this, SLOT(singleShotRequestZoteroUrl()));
-    } else
+        QTimer::singleShot((api->backoffSecondsLeft() + 1) * 1000, this, [ = ]() {
+        d->requestZoteroUrl(url);
+    });
+    else
         d->requestZoteroUrl(url);
 }
 
@@ -157,7 +158,7 @@ QString Collection::collectionFromNumericId(uint numericId) const
 
     // TODO make those resolutions more efficient
     const QList<QString> keys = d->collectionToLabel.keys();
-    foreach (const QString &key, keys) {
+    for (const QString &key : keys) {
         if (numericId == qHash(key))
             return key;
     }
@@ -186,20 +187,20 @@ void Collection::finishedFetchingCollection()
         QXmlStreamReader xmlReader(reply);
         while (!xmlReader.atEnd() && !xmlReader.hasError()) {
             const QXmlStreamReader::TokenType tt = xmlReader.readNext();
-            if (tt == QXmlStreamReader::StartElement && xmlReader.name() == QLatin1String("title")) {
+            if (tt == QXmlStreamReader::StartElement && xmlReader.name() == QStringLiteral("title")) {
                 /// Not perfect: guess author name from collection's title
-                const QStringList titleFragments = xmlReader.readElementText(QXmlStreamReader::IncludeChildElements).split(QLatin1String(" / "));
+                const QStringList titleFragments = xmlReader.readElementText(QXmlStreamReader::IncludeChildElements).split(QStringLiteral(" / "));
                 if (titleFragments.count() == 3)
                     d->collectionToLabel[Private::top] = i18n("%1's Library", titleFragments[1]);
-            } else if (tt == QXmlStreamReader::StartElement && xmlReader.name() == QLatin1String("entry")) {
+            } else if (tt == QXmlStreamReader::StartElement && xmlReader.name() == QStringLiteral("entry")) {
                 QString title, key;
                 while (!xmlReader.atEnd() && !xmlReader.hasError()) {
                     const QXmlStreamReader::TokenType tt = xmlReader.readNext();
-                    if (tt == QXmlStreamReader::StartElement && xmlReader.name() == QLatin1String("title"))
+                    if (tt == QXmlStreamReader::StartElement && xmlReader.name() == QStringLiteral("title"))
                         title = xmlReader.readElementText(QXmlStreamReader::IncludeChildElements);
-                    else if (tt == QXmlStreamReader::StartElement && xmlReader.name() == QLatin1String("key"))
+                    else if (tt == QXmlStreamReader::StartElement && xmlReader.name() == QStringLiteral("key"))
                         key = xmlReader.readElementText(QXmlStreamReader::IncludeChildElements);
-                    else if (tt == QXmlStreamReader::EndElement && xmlReader.name() == QLatin1String("entry"))
+                    else if (tt == QXmlStreamReader::EndElement && xmlReader.name() == QStringLiteral("entry"))
                         break;
                 }
 
@@ -211,32 +212,33 @@ void Collection::finishedFetchingCollection()
                     vec.append(key);
                     d->collectionToChildren[parentId] = vec;
                 }
-            } else if (tt == QXmlStreamReader::StartElement && xmlReader.name() == QLatin1String("link")) {
+            } else if (tt == QXmlStreamReader::StartElement && xmlReader.name() == QStringLiteral("link")) {
                 const QXmlStreamAttributes attrs = xmlReader.attributes();
-                if (attrs.hasAttribute(QLatin1String("rel")) && attrs.hasAttribute(QLatin1String("href")) && attrs.value(QLatin1String("rel")) == QLatin1String("next"))
-                    nextPage = attrs.value(QLatin1String("href")).toString();
-                else if (attrs.hasAttribute(QLatin1String("rel")) && attrs.hasAttribute(QLatin1String("href")) && attrs.value(QLatin1String("rel")) == QLatin1String("self")) {
-                    const QString text = attrs.value(QLatin1String("href")).toString();
-                    const int p1 = text.indexOf(QLatin1String("/collections/"));
-                    const int p2 = text.indexOf(QLatin1String("/"), p1 + 14);
+                if (attrs.hasAttribute(QStringLiteral("rel")) && attrs.hasAttribute(QStringLiteral("href")) && attrs.value(QStringLiteral("rel")) == QStringLiteral("next"))
+                    nextPage = attrs.value(QStringLiteral("href")).toString();
+                else if (attrs.hasAttribute(QStringLiteral("rel")) && attrs.hasAttribute(QStringLiteral("href")) && attrs.value(QStringLiteral("rel")) == QStringLiteral("self")) {
+                    const QString text = attrs.value(QStringLiteral("href")).toString();
+                    const int p1 = text.indexOf(QStringLiteral("/collections/"));
+                    const int p2 = text.indexOf(QStringLiteral("/"), p1 + 14);
                     if (p1 > 0 && p2 > p1 + 14)
                         parentId = text.mid(p1 + 13, p2 - p1 - 13);
                 }
-            } else if (tt == QXmlStreamReader::EndElement && xmlReader.name() == QLatin1String("feed"))
+            } else if (tt == QXmlStreamReader::EndElement && xmlReader.name() == QStringLiteral("feed"))
                 break;
         }
 
         if (!nextPage.isEmpty()) {
-            if (d->api->inBackoffMode() && d->queuedRequestZoteroUrl.isEmpty()) {
+            if (d->api->inBackoffMode())
                 /// If Zotero asked to 'back off', wait until this period is over before issuing the next request
-                d->queuedRequestZoteroUrl = nextPage;
-                QTimer::singleShot((d->api->backoffSecondsLeft() + 1) * 1000, this, SLOT(singleShotRequestZoteroUrl()));
-            } else
+                QTimer::singleShot((d->api->backoffSecondsLeft() + 1) * 1000, this, [ = ]() {
+                    d->requestZoteroUrl(nextPage);
+                });
+            else
                 d->requestZoteroUrl(nextPage);
         } else
             d->runNextInDownloadQueue();
     } else {
-        kWarning() << reply->errorString(); ///< something went wrong
+        qCWarning(LOG_KBIBTEX_NETWORKING) << reply->errorString(); ///< something went wrong
         d->initialized = false;
         emitFinishedLoading();
     }
@@ -247,8 +249,3 @@ void Collection::emitFinishedLoading()
     d->busy = false;
     emit finishedLoading();
 }
-
-void Collection::singleShotRequestZoteroUrl() {
-    d->requestZoteroUrl(d->queuedRequestZoteroUrl);
-    d->queuedRequestZoteroUrl.clear();
-}
