@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,21 +12,21 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #include "bibliographyservice.h"
 
+#include <QStandardPaths>
+
 #include <KSharedConfig>
 #include <KConfigGroup>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KMessageBox>
 
 class BibliographyService::Private
 {
 private:
-    // UNUSED BibliographyService *p;
-
     /// Representing configuration file "mimeapps.list"
     /// see http://www.freedesktop.org/wiki/Specifications/mime-actions-spec/
     KSharedConfig::Ptr configXDGMimeAppsList;
@@ -43,22 +43,17 @@ private:
 
 public:
     QWidget *parentWidget;
-    const QStringList textBasedMimeTypes;
+    static const QStringList textBasedMimeTypes;
 
-    Private(QWidget *w, BibliographyService */* UNUSED parent*/)
-        : // UNUSED p(parent),
-          configXDGMimeAppsList(KSharedConfig::openConfig(QLatin1String("mimeapps.list"), KConfig::NoGlobals, "xdgdata-apps")),
+    Private(QWidget *w, BibliographyService *parent)
+            : configXDGMimeAppsList(KSharedConfig::openConfig(QStringLiteral("mimeapps.list"), KConfig::NoGlobals, QStandardPaths::ApplicationsLocation)),
           configGroupAddedKDEServiceAssociations(configXDGMimeAppsList, "Added KDE Service Associations"),
           configGroupRemovedKDEServiceAssociations(configXDGMimeAppsList, "Removed KDE Service Associations"),
           configGroupAddedAssociations(configXDGMimeAppsList, "Added Associations"),
           configGroupRemovedAssociations(configXDGMimeAppsList, "Removed Associations"),
-          parentWidget(w),
-          textBasedMimeTypes(QStringList()
-                             << QLatin1String("text/x-bibtex") ///< classical BibTeX bibliographies
-                             << QLatin1String("application/x-research-info-systems") ///< Research Information Systems (RIS) bibliographies
-                             << QLatin1String("application/x-isi-export-format")) ///< Information Sciences Institute (ISI) bibliographies
+          parentWidget(w)
     {
-        /// nothing
+        Q_UNUSED(parent)
     }
 
     bool setKBibTeXforMimeType(const QString &mimetype, const bool isPlainTextFormat) {
@@ -156,10 +151,15 @@ public:
     }
 };
 
-const QString BibliographyService::Private::kbibtexApplicationDesktop = QLatin1String("kde4-kbibtex.desktop");
-const QString BibliographyService::Private::kbibtexPartDesktop = QLatin1String("kbibtexpart.desktop");
-const QString BibliographyService::Private::kateApplicationDesktop = QLatin1String("kde4-kate.desktop");
-const QString BibliographyService::Private::katePartDesktop = QLatin1String("katepart.desktop");
+const QString BibliographyService::Private::kbibtexApplicationDesktop = QStringLiteral("org.kde.kbibtex.desktop");
+const QString BibliographyService::Private::kbibtexPartDesktop = QStringLiteral("kbibtexpart.desktop");
+const QString BibliographyService::Private::kateApplicationDesktop = QStringLiteral("org.kde.kate.desktop");
+const QString BibliographyService::Private::katePartDesktop = QStringLiteral("katepart.desktop");
+const QStringList BibliographyService::Private::textBasedMimeTypes {
+    QStringLiteral("text/x-bibtex"), ///< classical BibTeX bibliographies
+    QStringLiteral("application/x-research-info-systems"), ///< Research Information Systems (RIS) bibliographies
+    QStringLiteral("application/x-isi-export-format") ///< Information Sciences Institute (ISI) bibliographies
+};
 
 BibliographyService::BibliographyService(QWidget *parentWidget)
         : QObject(parentWidget), d(new BibliographyService::Private(parentWidget, this))
@@ -174,19 +174,19 @@ BibliographyService::~BibliographyService()
 
 void BibliographyService::setKBibTeXasDefault() {
     /// Go through all supported mime types
-    foreach (const QString &mimeType, d->textBasedMimeTypes) {
+    for (const QString &mimeType : d->textBasedMimeTypes) {
         d->setKBibTeXforMimeType(mimeType, true);
     }
 
-    /// kbuildsycoca4 has to be run to update the mime type associations
-    QProcess *kbuildsycoca4Process = new QProcess(d->parentWidget);
-    connect(kbuildsycoca4Process, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(kbuildsycoca4finished(int,QProcess::ExitStatus)));
-    kbuildsycoca4Process->start(QLatin1String("kbuildsycoca4"));
+    /// kbuildsycoca5 has to be run to update the mime type associations
+    QProcess *kbuildsycoca5Process = new QProcess(d->parentWidget);
+    connect(kbuildsycoca5Process, static_cast<void(QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, &BibliographyService::kbuildsycoca5finished);
+    kbuildsycoca5Process->start(QStringLiteral("kbuildsycoca5"), QStringList());
 }
 
 bool BibliographyService::isKBibTeXdefault() const {
     /// Go through all supported mime types
-    foreach (const QString &mimeType, d->textBasedMimeTypes) {
+    for (const QString &mimeType : d->textBasedMimeTypes) {
         /// Test if KBibTeX is default handler for mime type
         if (!d->isKBibTeXdefaultForMimeType(mimeType))
             return false; ///< Failing any test means KBibTeX is not default application/part
@@ -194,7 +194,7 @@ bool BibliographyService::isKBibTeXdefault() const {
     return true; ///< All tests passed, KBibTeX is default application/part
 }
 
-void BibliographyService::kbuildsycoca4finished(int exitCode, QProcess::ExitStatus exitStatus) {
+void BibliographyService::kbuildsycoca5finished(int exitCode, QProcess::ExitStatus exitStatus) {
     if (exitCode != 0 || exitStatus != QProcess::NormalExit)
-        KMessageBox::error(d->parentWidget, i18n("Failed to run 'kbuildsycoca4' to update mime type associations.\n\nThe system may not know how to use KBibTeX to open bibliography files."), i18n("Failed to run 'kbuildsycoca4'"));
+        KMessageBox::error(d->parentWidget, i18n("Failed to run 'kbuildsycoca5' to update mime type associations.\n\nThe system may not know how to use KBibTeX to open bibliography files."), i18n("Failed to run 'kbuildsycoca5'"));
 }
