@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,7 +12,7 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #ifndef KBIBTEX_PROGRAM_ELEMENTFORM_H
@@ -33,10 +33,10 @@ class ElementForm : public QWidget
 
 public:
     ElementForm(MDIWidget *mdiWidget, QDockWidget *parent);
-    ~ElementForm();
+    ~ElementForm() override;
 
 public slots:
-    void setElement(QSharedPointer<Element>, File *);
+    void setElement(QSharedPointer<Element>, const File *);
     void refreshElement();
 
 signals:
@@ -49,6 +49,7 @@ private:
 private slots:
     void modified(bool);
     void apply();
+    bool validateAndOnlyThenApply();
     void reset();
     void visibilityChanged(bool);
     void autoApplyToggled(bool);
