@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                              and contributors                           *
  *                                                                         *
  *   Contributions to this file were made by                               *
@@ -16,7 +16,7 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #include "referencepreview.h"
@@ -27,20 +27,25 @@
 #include <QLayout>
 #include <QApplication>
 #include <QTextStream>
+#include <QTemporaryFile>
 #include <QPalette>
+#include <QMimeType>
+#include <QDebug>
+#include <QFileDialog>
+#include <QPushButton>
+#include <QFontDatabase>
 
-#include <KTemporaryFile>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KComboBox>
-#include <KStandardDirs>
-#include <KPushButton>
-#include <KFileDialog>
-#include <KDebug>
-#include <KMimeType>
 #include <KRun>
-#include <KIO/NetAccess>
+#include <KIO/CopyJob>
+#include <KJobWidgets>
+#include <KSharedConfig>
+#include <KConfigGroup>
 #include <KTextEdit>
+#include <kio_version.h>
 
+#include "xsltransform.h"
 #include "fileexporterbibtex.h"
 #include "fileexporterbibtex2html.h"
 #include "fileexporterris.h"
@@ -49,27 +54,27 @@
 #include "file.h"
 #include "entry.h"
 #include "fileview.h"
+#include "logging_program.h"
 
 static const struct PreviewStyles {
     QString label, style, type;
 }
 previewStyles[] = {
-    {i18n("Source (BibTeX)"), QLatin1String("bibtex"), QLatin1String("exporter")},
-    {i18n("Source (RIS)"), QLatin1String("ris"), QLatin1String("exporter")},
-    {QLatin1String("abbrv"), QLatin1String("abbrv"), QLatin1String("bibtex2html")},
-    {QLatin1String("acm"), QLatin1String("acm"), QLatin1String("bibtex2html")},
-    {QLatin1String("alpha"), QLatin1String("alpha"), QLatin1String("bibtex2html")},
-    {QLatin1String("apalike"), QLatin1String("apalike"), QLatin1String("bibtex2html")},
-    {QLatin1String("ieeetr"), QLatin1String("ieeetr"), QLatin1String("bibtex2html")},
-    {QLatin1String("plain"), QLatin1String("plain"), QLatin1String("bibtex2html")},
-    {QLatin1String("siam"), QLatin1String("siam"), QLatin1String("bibtex2html")},
-    {QLatin1String("unsrt"), QLatin1String("unsrt"), QLatin1String("bibtex2html")},
-    {i18n("Standard"), QLatin1String("standard"), QLatin1String("xml")},
-    {i18n("Fancy"), QLatin1String("fancy"), QLatin1String("xml")},
-    {i18n("Wikipedia Citation"), QLatin1String("wikipedia-cite"), QLatin1String("plain_xml")},
-    {i18n("Abstract-only"), QLatin1String("abstractonly"), QLatin1String("xml")}
+    {i18n("Source (BibTeX)"), QStringLiteral("bibtex"), QStringLiteral("exporter")},
+    {i18n("Source (RIS)"), QStringLiteral("ris"), QStringLiteral("exporter")},
+    {QStringLiteral("abbrv"), QStringLiteral("abbrv"), QStringLiteral("bibtex2html")},
+    {QStringLiteral("acm"), QStringLiteral("acm"), QStringLiteral("bibtex2html")},
+    {QStringLiteral("alpha"), QStringLiteral("alpha"), QStringLiteral("bibtex2html")},
+    {QStringLiteral("apalike"), QStringLiteral("apalike"), QStringLiteral("bibtex2html")},
+    {QStringLiteral("ieeetr"), QStringLiteral("ieeetr"), QStringLiteral("bibtex2html")},
+    {QStringLiteral("plain"), QStringLiteral("plain"), QStringLiteral("bibtex2html")},
+    {QStringLiteral("siam"), QStringLiteral("siam"), QStringLiteral("bibtex2html")},
+    {QStringLiteral("unsrt"), QStringLiteral("unsrt"), QStringLiteral("bibtex2html")},
+    {i18n("Standard"), QStringLiteral("standard"), QStringLiteral("xml")},
+    {i18n("Fancy"), QStringLiteral("fancy"), QStringLiteral("xml")},
+    {i18n("Wikipedia Citation"), QStringLiteral("wikipedia-cite"), QStringLiteral("plain_xml")},
+    {i18n("Abstract-only"), QStringLiteral("abstractonly"), QStringLiteral("xml")}
 };
-static const int previewStylesLen = sizeof(previewStyles) / sizeof(previewStyles[0]);
 
 Q_DECLARE_METATYPE(PreviewStyles)
 
@@ -83,7 +88,7 @@ public:
     const QString configGroupName;
     const QString configKeyName;
 
-    KPushButton *buttonOpen, *buttonSaveAsHTML;
+    QPushButton *buttonOpen, *buttonSaveAsHTML;
     QString htmlText;
     QUrl baseUrl;
     QTextDocument *htmlDocument;
@@ -98,12 +103,12 @@ public:
     const QString notAvailableMessage;
 
     ReferencePreviewPrivate(ReferencePreview *parent)
-            : p(parent), config(KSharedConfig::openConfig(QLatin1String("kbibtexrc"))), configGroupName(QLatin1String("Reference Preview Docklet")),
-          configKeyName(QLatin1String("Style")), file(NULL), fileView(NULL),
+            : p(parent), config(KSharedConfig::openConfig(QStringLiteral("kbibtexrc"))), configGroupName(QStringLiteral("Reference Preview Docklet")),
+          configKeyName(QStringLiteral("Style")), file(nullptr), fileView(nullptr),
           textColor(QApplication::palette().text().color()),
-          defaultFontSize(KGlobalSettings::generalFont().pointSize()),
-          htmlStart("<html>\n<head>\n<meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\" />\n<style type=\"text/css\">\npre {\n white-space: pre-wrap;\n white-space: -moz-pre-wrap;\n white-space: -pre-wrap;\n white-space: -o-pre-wrap;\n word-wrap: break-word;\n}\n</style>\n</head>\n<body style=\"color: " + textColor.name() + "; font-size: " + QString::number(defaultFontSize) + "pt; font-family: '" + KGlobalSettings::generalFont().family() + "'; background-color: '" + QApplication::palette().base().color().name() + "';\">"),
-          notAvailableMessage(htmlStart + "<p style=\"font-style: italic;\">" + i18n("No preview available") + "</p><p style=\"font-size: 90%;\">" + i18n("Reason:") + " %1</p></body></html>") {
+          defaultFontSize(QFontDatabase::systemFont(QFontDatabase::GeneralFont).pointSize()),
+          htmlStart(QStringLiteral("<html>\n<head>\n<meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\" />\n<style type=\"text/css\">\npre {\n white-space: pre-wrap;\n white-space: -moz-pre-wrap;\n white-space: -pre-wrap;\n white-space: -o-pre-wrap;\n word-wrap: break-word;\n}\n</style>\n</head>\n<body style=\"color: ") + textColor.name() + QStringLiteral("; font-size: ") + QString::number(defaultFontSize) + QStringLiteral("pt; font-family: '") + QFontDatabase::systemFont(QFontDatabase::GeneralFont).family() + QStringLiteral("'; background-color: '") + QApplication::palette().base().color().name(QColor::HexRgb) + QStringLiteral("'\">")),
+          notAvailableMessage(htmlStart + QStringLiteral("<p style=\"font-style: italic;\">") + i18n("No preview available") + QStringLiteral("</p><p style=\"font-size: 90%;\">") + i18n("Reason:") + QStringLiteral(" %1</p></body></html>")) {
         QGridLayout *gridLayout = new QGridLayout(p);
         gridLayout->setMargin(0);
         gridLayout->setColumnStretch(0, 1);
@@ -126,34 +131,38 @@ public:
         htmlView->setDocument(htmlDocument);
         layout->addWidget(htmlView);
 
-        buttonOpen = new KPushButton(KIcon("document-open"), i18n("Open"), p);
+        buttonOpen = new QPushButton(QIcon::fromTheme(QStringLiteral("document-open")), i18n("Open"), p);
         buttonOpen->setToolTip(i18n("Open reference in web browser."));
         gridLayout->addWidget(buttonOpen, 2, 1, 1, 1);
 
-        buttonSaveAsHTML = new KPushButton(KIcon("document-save"), i18n("Save as HTML"), p);
+        buttonSaveAsHTML = new QPushButton(QIcon::fromTheme(QStringLiteral("document-save")), i18n("Save as HTML"), p);
         buttonSaveAsHTML->setToolTip(i18n("Save reference as HTML fragment."));
         gridLayout->addWidget(buttonSaveAsHTML, 2, 2, 1, 1);
     }
 
-    bool saveHTML(const KUrl &url) const {
-        KTemporaryFile tempFile;
+    bool saveHTML(const QUrl &url) const {
+        QTemporaryFile tempFile;
         tempFile.setAutoRemove(true);
 
         bool result = saveHTML(tempFile);
 
         if (result) {
-            KIO::NetAccess::del(url, p); /// ignore error if tempFile does not exist
-            result = KIO::NetAccess::file_copy(KUrl(tempFile.fileName()), url, p);
+            KIO::CopyJob *copyJob = KIO::copy(QUrl::fromLocalFile(tempFile.fileName()), url, KIO::Overwrite);
+            KJobWidgets::setWindow(copyJob, p);
+            result = copyJob->exec();
         }
 
         return result;
     }
 
-    bool saveHTML(KTemporaryFile &tempFile) const {
+    bool saveHTML(QTemporaryFile &tempFile) const {
         if (tempFile.open()) {
             QTextStream ts(&tempFile);
             ts.setCodec("utf-8");
-            ts << QString(htmlText).replace(QRegExp("<a[^>]+href=\"kbibtex:[^>]+>([^<]+)</a>"), "\\1");
+            static const QRegularExpression kbibtexHrefRegExp(QStringLiteral("<a[^>]+href=\"kbibtex:[^>]+>(.+?)</a>"));
+            QString modifiedHtmlText = htmlText;
+            modifiedHtmlText = modifiedHtmlText.replace(kbibtexHrefRegExp, QStringLiteral("\\1"));
+            ts << modifiedHtmlText;
             tempFile.close();
             return true;
         }
@@ -162,17 +171,18 @@ public:
     }
 
     void loadState() {
-        static bool hasBibTeX2HTML = !KStandardDirs::findExe(QLatin1String("bibtex2html")).isEmpty();
+        static bool hasBibTeX2HTML = !QStandardPaths::findExecutable(QStringLiteral("bibtex2html")).isEmpty();
 
-        int styleIndex = 0;
         KConfigGroup configGroup(config, configGroupName);
         const QString previousStyle = configGroup.readEntry(configKeyName, QString());
 
         comboBox->clear();
-        for (int i = 0, c = 0; i < previewStylesLen; ++i) {
-            if (!hasBibTeX2HTML && previewStyles[i].type.contains(QLatin1String("bibtex2html"))) continue;
-            comboBox->addItem(previewStyles[i].label, QVariant::fromValue(previewStyles[i]));
-            if (previousStyle == previewStyles[i].style)
+
+        int styleIndex = 0, c = 0;
+        for (const PreviewStyles &previewStyle : previewStyles) {
+            if (!hasBibTeX2HTML && previewStyle.type.contains(QStringLiteral("bibtex2html"))) continue;
+            comboBox->addItem(previewStyle.label, QVariant::fromValue(previewStyle));
+            if (previousStyle == previewStyle.style)
                 styleIndex = c;
             ++c;
         }
@@ -191,9 +201,9 @@ ReferencePreview::ReferencePreview(QWidget *parent)
 {
     d->loadState();
 
-    connect(d->buttonOpen, SIGNAL(clicked()), this, SLOT(openAsHTML()));
-    connect(d->buttonSaveAsHTML, SIGNAL(clicked()), this, SLOT(saveAsHTML()));
-    connect(d->comboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(renderHTML()));
+    connect(d->buttonOpen, &QPushButton::clicked, this, &ReferencePreview::openAsHTML);
+    connect(d->buttonSaveAsHTML, &QPushButton::clicked, this, &ReferencePreview::saveAsHTML);
+    connect(d->comboBox, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &ReferencePreview::renderHTML);
 
     setEnabled(false);
 }
@@ -205,7 +215,7 @@ ReferencePreview::~ReferencePreview()
 
 void ReferencePreview::setHtml(const QString &html, bool buttonsEnabled)
 {
-    d->htmlText = QString(html).remove(QLatin1String("<?xml version=\"1.0\" encoding=\"UTF-8\"?>"));
+    d->htmlText = QString(html).remove(QStringLiteral("<?xml version=\"1.0\" encoding=\"UTF-8\"?>"));
     d->htmlDocument->setHtml(d->htmlText);
     d->buttonOpen->setEnabled(buttonsEnabled);
     d->buttonSaveAsHTML->setEnabled(buttonsEnabled);
@@ -221,7 +231,7 @@ void ReferencePreview::setEnabled(bool enabled)
     d->comboBox->setEnabled(enabled);
 }
 
-void ReferencePreview::setElement(QSharedPointer<Element> element, File *file)
+void ReferencePreview::setElement(QSharedPointer<Element> element, const File *file)
 {
     d->element = element;
     d->file = file;
@@ -242,34 +252,32 @@ void ReferencePreview::renderHTML()
 
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
-    FileExporter *exporter = NULL;
+    FileExporter *exporter = nullptr;
 
     const PreviewStyles previewStyle = d->comboBox->itemData(d->comboBox->currentIndex()).value<PreviewStyles>();
 
-    // FIXME 'add' case is never used, see Coverity Scan CID 90363
-
-    if (previewStyle.type == QLatin1String("exporter")) {
-        if (previewStyle.style == QLatin1String("bibtex")) {
-            FileExporterBibTeX *exporterBibTeX = new FileExporterBibTeX();
-            exporterBibTeX->setEncoding(QLatin1String("utf-8"));
+    if (previewStyle.type == QStringLiteral("exporter")) {
+        if (previewStyle.style == QStringLiteral("bibtex")) {
+            FileExporterBibTeX *exporterBibTeX = new FileExporterBibTeX(this);
+            exporterBibTeX->setEncoding(QStringLiteral("utf-8"));
             exporter = exporterBibTeX;
-        } else if (previewStyle.style == QLatin1String("ris"))
-            exporter = new FileExporterRIS();
-    } else if (previewStyle.type == QLatin1String("bibtex2html")) {
+        } else if (previewStyle.style == QStringLiteral("ris"))
+            exporter = new FileExporterRIS(this);
+        else
+            qCWarning(LOG_KBIBTEX_PROGRAM) << "Don't know how to handle output style " << previewStyle.style << " for type " << previewStyle.type;
+    } else if (previewStyle.type == QStringLiteral("bibtex2html")) {
         crossRefHandling = merge;
-        FileExporterBibTeX2HTML *exporterHTML = new FileExporterBibTeX2HTML();
+        FileExporterBibTeX2HTML *exporterHTML = new FileExporterBibTeX2HTML(this);
         exporterHTML->setLaTeXBibliographyStyle(previewStyle.style);
         exporter = exporterHTML;
-    } else if (previewStyle.type == QLatin1String("xml") || previewStyle.type.endsWith(QLatin1String("_xml"))) {
+    } else if (previewStyle.type == QStringLiteral("xml") || previewStyle.type.endsWith(QStringLiteral("_xml"))) {
         crossRefHandling = merge;
-        FileExporterXSLT *exporterXSLT = new FileExporterXSLT();
-        QString filename = previewStyle.style + ".xsl";
-        exporterXSLT->setXSLTFilename(KStandardDirs::locate("data", QLatin1String("kbibtex/") + filename));
-        exporter = exporterXSLT;
+        const QString filename = previewStyle.style + QStringLiteral(".xsl");
+        exporter = new FileExporterXSLT(XSLTransform::locateXSLTfile(filename), this);
     } else
-        kWarning() << "Don't know how to handle output type " << previewStyle.type;
+        qCWarning(LOG_KBIBTEX_PROGRAM) << "Don't know how to handle output type " << previewStyle.type;
 
-    if (exporter != NULL) {
+    if (exporter != nullptr) {
         QBuffer buffer(this);
         buffer.open(QBuffer::WriteOnly);
 
@@ -278,7 +286,7 @@ void ReferencePreview::renderHTML()
         QSharedPointer<const Entry> entry = d->element.dynamicCast<const Entry>();
         /** NOT USED
         if (crossRefHandling == add && !entry.isNull()) {
-            QString crossRef = PlainTextValue::text(entry->value(QLatin1String("crossref")));
+            QString crossRef = PlainTextValue::text(entry->value(QStringLiteral("crossref")));
             QSharedPointer<const Entry> crossRefEntry = d->file == NULL ? QSharedPointer<const Entry>() : d->file->containsKey(crossRef) .dynamicCast<const Entry>();
             if (!crossRefEntry.isNull()) {
                 File file;
@@ -289,7 +297,7 @@ void ReferencePreview::renderHTML()
                 exporterResult = exporter->save(&buffer, d->element, d->file, &errorLog);
         } else */
         if (crossRefHandling == merge && !entry.isNull()) {
-            QSharedPointer<Entry> merged = QSharedPointer<Entry>(Entry::resolveCrossref(*entry, d->file));
+            QSharedPointer<Entry> merged = QSharedPointer<Entry>(entry->resolveCrossref(d->file));
             exporterResult = exporter->save(&buffer, merged, d->file, &errorLog);
         } else
             exporterResult = exporter->save(&buffer, d->element, d->file, &errorLog);
@@ -304,64 +312,63 @@ void ReferencePreview::renderHTML()
 
         if (!exporterResult || text.isEmpty()) {
             /// something went wrong, no output ...
-            text = d->notAvailableMessage.arg(i18n("No HTML output generated"));
+            text = d->notAvailableMessage.arg(i18n("No output generated"));
             buttonsEnabled = false;
-            kDebug() << errorLog.join("\n");
+            qCDebug(LOG_KBIBTEX_PROGRAM) << errorLog.join(QStringLiteral("\n"));
         } else {
             /// beautify text
-            text.replace(QLatin1String("``"), QLatin1String("&ldquo;"));
-            text.replace(QLatin1String("''"), QLatin1String("&rdquo;"));
-            static const QRegExp openingSingleQuotationRegExp(QLatin1String("(^|[> ,.;:!?])`(\\S)"));
-            static const QRegExp closingSingleQuotationRegExp(QLatin1String("(\\S)'([ ,.;:!?<]|$)"));
-            text.replace(openingSingleQuotationRegExp, QLatin1String("\\1&lsquo;\\2"));
-            text.replace(closingSingleQuotationRegExp, QLatin1String("\\1&rsquo;\\2"));
+            text.replace(QStringLiteral("``"), QStringLiteral("&ldquo;"));
+            text.replace(QStringLiteral("''"), QStringLiteral("&rdquo;"));
+            static const QRegularExpression openingSingleQuotationRegExp(QStringLiteral("(^|[> ,.;:!?])`(\\S)"));
+            static const QRegularExpression closingSingleQuotationRegExp(QStringLiteral("(\\S)'([ ,.;:!?<]|$)"));
+            text.replace(openingSingleQuotationRegExp, QStringLiteral("\\1&lsquo;\\2"));
+            text.replace(closingSingleQuotationRegExp, QStringLiteral("\\1&rsquo;\\2"));
 
-            if (previewStyle.style == QLatin1String("wikipedia-cite"))
-                text.remove(QLatin1String("\n"));
+            if (previewStyle.style == QStringLiteral("wikipedia-cite"))
+                text.remove(QStringLiteral("\n"));
 
-            if (text.contains(QLatin1String("{{cite FIXME"))) {
+            if (text.contains(QStringLiteral("{{cite FIXME"))) {
                 /// Wikipedia {{cite ...}} command had problems (e.g. unknown entry type)
                 text = d->notAvailableMessage.arg(i18n("This type of element is not supported by Wikipedia's <tt>{{cite}}</tt> command."));
-            } else if (previewStyle.type == QLatin1String("exporter") || previewStyle.type.startsWith(QLatin1String("plain_"))) {
+            } else if (previewStyle.type == QStringLiteral("exporter") || previewStyle.type.startsWith(QStringLiteral("plain_"))) {
                 /// source
-                text.prepend(QLatin1String("';\">"));
-                text.prepend(KGlobalSettings::fixedFont().family());
-                text.prepend(QLatin1String("<pre style=\"font-family: '"));
+                text.prepend(QStringLiteral("';\">"));
+                text.prepend(QFontDatabase::systemFont(QFontDatabase::FixedFont).family());
+                text.prepend(QStringLiteral("<pre style=\"font-family: '"));
                 text.prepend(d->htmlStart);
-                text.append(QLatin1String("</pre></body></html>"));
-            } else if (previewStyle.type == QLatin1String("bibtex2html")) {
+                text.append(QStringLiteral("</pre></body></html>"));
+            } else if (previewStyle.type == QStringLiteral("bibtex2html")) {
                 /// bibtex2html
 
                 /// remove "generated by" line from HTML code if BibTeX2HTML was used
-                text.remove(QRegExp("<hr><p><em>.*</p>"));
-                text.remove(QRegExp("<[/]?(font)[^>]*>"));
-                QRegExp reTable("^.*<td.*</td.*<td>");
-                reTable.setMinimal(true);
-                text.remove(reTable);
-                text.remove(QRegExp("</td>.*$"));
-                QRegExp reAnchor("\\[ <a.*</a> \\]");
-                reAnchor.setMinimal(true);
-                text.remove(reAnchor);
+                text.remove(QRegularExpression(QStringLiteral("<hr><p><em>.*</p>")));
+                text.remove(QRegularExpression(QStringLiteral("<[/]?(font)[^>]*>")));
+                text.remove(QRegularExpression(QStringLiteral("^.*?<td.*?</td.*?<td>")));
+                text.remove(QRegularExpression(QStringLiteral("</td>.*$")));
+                text.remove(QRegularExpression(QStringLiteral("\\[ <a.*?</a> \\]")));
 
                 /// replace ASCII art with Unicode characters
-                text.replace(QLatin1String("---"), QString(QChar(0x2014)));
-                text.replace(QLatin1String("--"), QString(QChar(0x2013)));
+                text.replace(QStringLiteral("---"), QString(QChar(0x2014)));
+                text.replace(QStringLiteral("--"), QString(QChar(0x2013)));
 
                 text.prepend(d->htmlStart);
                 text.append("</body></html>");
-            } else if (previewStyle.type == QLatin1String("xml")) {
+            } else if (previewStyle.type == QStringLiteral("xml")) {
                 /// XML/XSLT
                 text.prepend(d->htmlStart);
                 text.append("</body></html>");
             }
 
             /// adopt current color scheme
-            text.replace(QLatin1String("color: black;"), QString(QLatin1String("color: %1;")).arg(d->textColor.name()));
+            text.replace(QStringLiteral("color: black;"), QString(QStringLiteral("color: %1;")).arg(d->textColor.name()));
         }
 
         setHtml(text, buttonsEnabled);
 
         d->saveState();
+    } else {
+        /// something went wrong, no exporter ...
+        setHtml(d->notAvailableMessage.arg(i18n("No output generated")), false);
     }
 
     QApplication::restoreOverrideCursor();
@@ -369,30 +376,33 @@ void ReferencePreview::renderHTML()
 
 void ReferencePreview::openAsHTML()
 {
-    KTemporaryFile file;
-    file.setSuffix(".html");
+    QTemporaryFile file(QStandardPaths::writableLocation(QStandardPaths::TempLocation) + QDir::separator() + QStringLiteral("referencePreview-openAsHTML-XXXXXX.html"));
     file.setAutoRemove(false); /// let file stay alive for browser
     d->saveHTML(file);
 
     /// Ask KDE subsystem to open url in viewer matching mime type
-    KUrl url(file.fileName());
-    KRun::runUrl(url, QLatin1String("text/html"), this, false, false);
+    QUrl url(file.fileName());
+#if KIO_VERSION < 0x051f00 // < 5.31.0
+    KRun::runUrl(url, QStringLiteral("text/html"), this, false, false);
+#else // KIO_VERSION < 0x051f00 // >= 5.31.0
+    KRun::runUrl(url, QStringLiteral("text/html"), this, KRun::RunFlags());
+#endif // KIO_VERSION < 0x051f00
 }
 
 void ReferencePreview::saveAsHTML()
 {
-    KUrl url = KFileDialog::getSaveUrl(KUrl(), "text/html", this, i18n("Save as HTML"));
+    QUrl url = QFileDialog::getSaveFileUrl(this, i18n("Save as HTML"), QUrl(), QStringLiteral("text/html"));
     if (url.isValid())
         d->saveHTML(url);
 }
 
 void ReferencePreview::linkClicked(const QUrl &url)
 {
-    QString text = url.toString();
-    if (text.startsWith(QLatin1String("kbibtex:filter:"))) {
+    QString text = url.toDisplayString();
+    if (text.startsWith(QStringLiteral("kbibtex:filter:"))) {
         text = text.mid(15);
-        if (d->fileView != NULL) {
-            int p = text.indexOf("=");
+        if (d->fileView != nullptr) {
+            int p = text.indexOf(QStringLiteral("="));
             SortFilterFileModel::FilterQuery fq;
             fq.terms << text.mid(p + 1);
             fq.combination = SortFilterFileModel::EveryTerm;
