@@ -12,7 +12,7 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #include "zoterobrowser.h"
@@ -24,15 +24,14 @@
 #include <QFormLayout>
 #include <QAbstractItemModel>
 #include <QRadioButton>
-
-#include <KLocale>
-#include <KComboBox>
+#include <QPushButton>
+#include <QDebug>
 #include <KLineEdit>
-#include <KPushButton>
-#include <KConfigGroup>
+
+#include <KLocalizedString>
+#include <KComboBox>
+#include <KWallet/KWallet>
 #include <KMessageBox>
-#include <KDebug>
-#include <KWallet/Wallet>
 
 #include "element.h"
 #include "searchresults.h"
@@ -43,9 +42,9 @@
 #include "zotero/tags.h"
 #include "zotero/tagmodel.h"
 #include "zotero/api.h"
-#ifdef HAVE_QTOAUTH // krazy:exclude=cpp
 #include "zotero/oauthwizard.h"
-#endif // HAVE_QTOAUTH
+
+using KWallet::Wallet;
 
 class ZoteroBrowser::Private
 {
@@ -76,23 +75,23 @@ public:
 
     QCursor nonBusyCursor;
 
-    KWallet::Wallet *wallet;
+    Wallet *wallet;
     static const QString walletFolderOAuth, walletEntryKBibTeXZotero, walletKeyZoteroId, walletKeyZoteroApiKey;
 
     Private(SearchResults *sr, ZoteroBrowser *parent)
-            : p(parent), items(NULL), groups(NULL), tags(NULL), tagModel(NULL), collection(NULL), collectionModel(NULL), needToApplyCredentials(true), searchResults(sr), comboBoxGroupListInitialized(false), nonBusyCursor(p->cursor()), wallet(NULL) {
+            : p(parent), items(nullptr), groups(nullptr), tags(nullptr), tagModel(nullptr), collection(nullptr), collectionModel(nullptr), needToApplyCredentials(true), searchResults(sr), comboBoxGroupListInitialized(false), nonBusyCursor(p->cursor()), wallet(nullptr) {
         setupGUI();
     }
 
     ~Private() {
-        if (wallet != NULL)
+        if (wallet != nullptr)
             delete wallet;
-        if (items != NULL) delete items;
-        if (groups != NULL) delete groups;
-        if (tags != NULL) delete tags;
-        if (tagModel != NULL) delete tagModel;
-        if (collection != NULL) delete collection;
-        if (collectionModel != NULL) delete collectionModel;
+        if (items != nullptr) delete items;
+        if (groups != nullptr) delete groups;
+        if (tags != nullptr) delete tags;
+        if (tagModel != nullptr) delete tagModel;
+        if (collection != nullptr) delete collection;
+        if (collectionModel != nullptr) delete collectionModel;
         api.clear();
     }
 
@@ -103,8 +102,8 @@ public:
         layout->addWidget(tabWidget);
 
         QWidget *container = new QWidget(tabWidget);
-        tabWidget->addTab(container, KIcon("preferences-web-browser-identification"), i18n("Library"));
-        connect(tabWidget, SIGNAL(currentChanged(int)), p, SLOT(tabChanged(int)));
+        tabWidget->addTab(container, QIcon::fromTheme(QStringLiteral("preferences-web-browser-identification")), i18n("Library"));
+        connect(tabWidget, &QTabWidget::currentChanged, p, &ZoteroBrowser::tabChanged);
         QBoxLayout *containerLayout = new QVBoxLayout(container);
 
         /// Personal or Group Library
@@ -124,8 +123,9 @@ public:
         radioPersonalLibrary->setChecked(true);
         comboBoxGroupList->setEnabled(false);
         comboBoxGroupList->addItem(i18n("No groups available"));
-        connect(radioGroupLibrary, SIGNAL(toggled(bool)), p, SLOT(radioButtonsToggled()));
-        connect(radioPersonalLibrary, SIGNAL(toggled(bool)), p, SLOT(radioButtonsToggled()));
+        connect(radioGroupLibrary, &QRadioButton::toggled, p, &ZoteroBrowser::radioButtonsToggled);
+        connect(radioPersonalLibrary, &QRadioButton::toggled, p, &ZoteroBrowser::radioButtonsToggled);
+        connect(comboBoxGroupList, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), p, &ZoteroBrowser::groupListChanged);
 
         containerLayout->addStretch(10);
 
@@ -135,90 +135,72 @@ public:
         containerForm->setMargin(0);
         lineEditNumericUserId = new KLineEdit(container);
         lineEditNumericUserId->setSizePolicy(sizePolicy);
-#ifdef HAVE_QTOAUTH // krazy:exclude=cpp
-        /// If OAuth is available, make widget read-only
-        /// so that it can only be set through OAuth wizard
         lineEditNumericUserId->setReadOnly(true);
-#endif // not HAVE_QTOAUTH
         containerForm->addRow(i18n("Numeric user id:"), lineEditNumericUserId);
-        connect(lineEditNumericUserId, SIGNAL(textChanged(QString)), p, SLOT(invalidateGroupList()));
+        connect(lineEditNumericUserId, &KLineEdit::textChanged, p, &ZoteroBrowser::invalidateGroupList);
 
         lineEditApiKey = new KLineEdit(container);
         lineEditApiKey->setSizePolicy(sizePolicy);
-#ifdef HAVE_QTOAUTH // krazy:exclude=cpp
-/// If OAuth is available, make widget read-only
-/// so that it can only be set through OAuth wizard
         lineEditApiKey->setReadOnly(true);
-#endif // not HAVE_QTOAUTH
         containerForm->addRow(i18n("API key:"), lineEditApiKey);
-        connect(lineEditApiKey, SIGNAL(textChanged(QString)), p, SLOT(invalidateGroupList()));
+        connect(lineEditApiKey, &KLineEdit::textChanged, p, &ZoteroBrowser::invalidateGroupList);
 
         QBoxLayout *containerButtonLayout = new QHBoxLayout();
         containerLayout->addLayout(containerButtonLayout, 0);
         containerButtonLayout->setMargin(0);
-#ifdef HAVE_QTOAUTH // krazy:exclude=cpp
-        QPushButton *buttonGetOAuthCredentials = new QPushButton(QIcon::fromTheme(QLatin1String("preferences-web-browser-identification")), i18n("Get New Credentials"), container);
+        QPushButton *buttonGetOAuthCredentials = new QPushButton(QIcon::fromTheme(QStringLiteral("preferences-web-browser-identification")), i18n("Get New Credentials"), container);
         containerButtonLayout->addWidget(buttonGetOAuthCredentials, 0);
-        connect(buttonGetOAuthCredentials, SIGNAL(clicked()), p, SLOT(getOAuthCredentials()));
-#else // not HAVE_QTOAUTH
-        QPushButton *buttonApplyManuallyEnteredCredentials = new QPushButton(QIcon::fromTheme(QLatin1String("preferences-web-browser-identification")), i18n("Apply Credentials"), container);
-        containerButtonLayout->addWidget(buttonApplyManuallyEnteredCredentials, 0);
-        connect(buttonApplyManuallyEnteredCredentials, SIGNAL(clicked()), p, SLOT(applyManuallyEnteredCredentials()));
-#endif // not HAVE_QTOAUTH
+        connect(buttonGetOAuthCredentials, &QPushButton::clicked, p, &ZoteroBrowser::getOAuthCredentials);
         containerButtonLayout->addStretch(1);
 
         /// Collection browser
         collectionBrowser = new QTreeView(tabWidget);
-        tabWidget->addTab(collectionBrowser, KIcon("folder-yellow"), i18n("Collections"));
+        tabWidget->addTab(collectionBrowser, QIcon::fromTheme(QStringLiteral("folder-yellow")), i18n("Collections"));
         collectionBrowser->setHeaderHidden(true);
         collectionBrowser->setExpandsOnDoubleClick(false);
-        connect(collectionBrowser, SIGNAL(doubleClicked(QModelIndex)), p, SLOT(collectionDoubleClicked(QModelIndex)));
+        connect(collectionBrowser, &QTreeView::doubleClicked, p, &ZoteroBrowser::collectionDoubleClicked);
 
         /// Tag browser
         tagBrowser = new QListView(tabWidget);
-        tabWidget->addTab(tagBrowser, KIcon("mail-tagged"), i18n("Tags"));
-        connect(tagBrowser, SIGNAL(doubleClicked(QModelIndex)), p, SLOT(tagDoubleClicked(QModelIndex)));
+        tabWidget->addTab(tagBrowser, QIcon::fromTheme(QStringLiteral("mail-tagged")), i18n("Tags"));
+        connect(tagBrowser, &QListView::doubleClicked, p, &ZoteroBrowser::tagDoubleClicked);
     }
 
     void queueReadOAuthCredentials() {
-        if (wallet != NULL && wallet->isOpen())
+        if (wallet != nullptr && wallet->isOpen())
             p->readOAuthCredentials(true);
         else {
             /// Wallet is closed or not initialized
-            if (wallet != NULL)
+            if (wallet != nullptr)
                 /// Delete existing but closed wallet, will be replaced by new, open wallet soon
                 delete wallet;
-            wallet = KWallet::Wallet::openWallet(KWallet::Wallet::NetworkWallet(), p->winId(), KWallet::Wallet::Asynchronous);
-            if (wallet != NULL) {
-                p->setEnabled(false);
-                p->setCursor(Qt::WaitCursor);
-                connect(wallet, SIGNAL(walletOpened(bool)), p, SLOT(readOAuthCredentials(bool)));
-            }
+            p->setEnabled(false);
+            p->setCursor(Qt::WaitCursor);
+            wallet = Wallet::openWallet(Wallet::NetworkWallet(), p->winId(), Wallet::Asynchronous);
+            connect(wallet, &Wallet::walletOpened, p, &ZoteroBrowser::readOAuthCredentials);
         }
     }
 
     void queueWriteOAuthCredentials() {
-        if (wallet != NULL && wallet->isOpen())
+        if (wallet != nullptr && wallet->isOpen())
             p->writeOAuthCredentials(true);
         else {
             /// Wallet is closed or not initialized
-            if (wallet != NULL)
+            if (wallet != nullptr)
                 /// Delete existing but closed wallet, will be replaced by new, open wallet soon
                 delete wallet;
-            wallet = KWallet::Wallet::openWallet(KWallet::Wallet::NetworkWallet(), p->winId(), KWallet::Wallet::Asynchronous);
-            if (wallet != NULL) {
-                p->setEnabled(false);
-                p->setCursor(Qt::WaitCursor);
-                connect(wallet, SIGNAL(walletOpened(bool)), p, SLOT(writeOAuthCredentials(bool)));
-            }
+            p->setEnabled(false);
+            p->setCursor(Qt::WaitCursor);
+            wallet = Wallet::openWallet(Wallet::NetworkWallet(), p->winId(), Wallet::Asynchronous);
+            connect(wallet, &Wallet::walletOpened, p, &ZoteroBrowser::writeOAuthCredentials);
         }
     }
 };
 
-const QString ZoteroBrowser::Private::walletFolderOAuth = QLatin1String("OAuth");
-const QString ZoteroBrowser::Private::walletEntryKBibTeXZotero = QLatin1String("KBibTeX/Zotero");
-const QString ZoteroBrowser::Private::walletKeyZoteroId = QLatin1String("UserId");
-const QString ZoteroBrowser::Private::walletKeyZoteroApiKey = QLatin1String("ApiKey");
+const QString ZoteroBrowser::Private::walletFolderOAuth = QStringLiteral("OAuth");
+const QString ZoteroBrowser::Private::walletEntryKBibTeXZotero = QStringLiteral("KBibTeX/Zotero");
+const QString ZoteroBrowser::Private::walletKeyZoteroId = QStringLiteral("UserId");
+const QString ZoteroBrowser::Private::walletKeyZoteroApiKey = QStringLiteral("ApiKey");
 
 ZoteroBrowser::ZoteroBrowser(SearchResults *searchResults, QWidget *parent)
         : QWidget(parent), d(new ZoteroBrowser::Private(searchResults, this))
@@ -251,7 +233,7 @@ void ZoteroBrowser::modelReset()
     }
 
     if (!d->tags->busy() && !d->collection->busy() && !(d->collection->initialized() && d->tags->initialized()))
-        KMessageBox::sorry(this, i18n("KBibTeX failed to retrieve the bibliography from Zotero. Please check that the provided user id and API key are valid."), i18n("Failed to retrieve data from Zotero"));
+        KMessageBox::information(this, i18n("KBibTeX failed to retrieve the bibliography from Zotero. Please check that the provided user id and API key are valid."), i18n("Failed to retrieve data from Zotero"));
 }
 
 void ZoteroBrowser::collectionDoubleClicked(const QModelIndex &index)
@@ -307,11 +289,11 @@ bool ZoteroBrowser::applyCredentials()
         int groupId = d->comboBoxGroupList->itemData(d->comboBoxGroupList->currentIndex()).toInt(&ok);
         if (!ok) groupId = -1;
 
-        disconnect(d->tags, SIGNAL(finishedLoading()), this, SLOT(reenableWidget()));
-        disconnect(d->items, SIGNAL(stoppedSearch(int)), this, SLOT(reenableWidget()));
-        disconnect(d->items, SIGNAL(foundElement(QSharedPointer<Element>)), this, SLOT(showItem(QSharedPointer<Element>)));
-        disconnect(d->tagModel, SIGNAL(modelReset()), this, SLOT(modelReset()));
-        disconnect(d->collectionModel, SIGNAL(modelReset()), this, SLOT(modelReset()));
+        disconnect(d->tags, &Zotero::Tags::finishedLoading, this, &ZoteroBrowser::reenableWidget);
+        disconnect(d->items, &Zotero::Items::stoppedSearch, this, &ZoteroBrowser::reenableWidget);
+        disconnect(d->items, &Zotero::Items::foundElement, this, &ZoteroBrowser::showItem);
+        disconnect(d->tagModel, &Zotero::TagModel::modelReset, this, &ZoteroBrowser::modelReset);
+        disconnect(d->collectionModel, &Zotero::CollectionModel::modelReset, this, &ZoteroBrowser::modelReset);
 
         d->collection->deleteLater();
         d->items->deleteLater();
@@ -321,7 +303,7 @@ bool ZoteroBrowser::applyCredentials()
         d->api.clear();
 
         const bool makeGroupRequest = d->radioGroupLibrary->isChecked() && groupId > 0;
-        d->api = QSharedPointer<Zotero::API>(new Zotero::API(makeGroupRequest ? Zotero::API::GroupRequest : Zotero::API::UserRequest, makeGroupRequest ? groupId : userId, apiKey, this));
+        d->api = QSharedPointer<Zotero::API>(new Zotero::API(makeGroupRequest ? Zotero::API::GroupRequest : Zotero::API::UserRequest, makeGroupRequest ? groupId : userId, d->lineEditApiKey->text(), this));
         d->items = new Zotero::Items(d->api, this);
         d->tags = new Zotero::Tags(d->api, this);
         d->tagModel = new Zotero::TagModel(d->tags, this);
@@ -330,11 +312,11 @@ bool ZoteroBrowser::applyCredentials()
         d->collectionModel = new Zotero::CollectionModel(d->collection, this);
         d->collectionBrowser->setModel(d->collectionModel);
 
-        connect(d->collectionModel, SIGNAL(modelReset()), this, SLOT(modelReset()));
-        connect(d->tagModel, SIGNAL(modelReset()), this, SLOT(modelReset()));
-        connect(d->items, SIGNAL(foundElement(QSharedPointer<Element>)), this, SLOT(showItem(QSharedPointer<Element>)));
-        connect(d->items, SIGNAL(stoppedSearch(int)), this, SLOT(reenableWidget()));
-        connect(d->tags, SIGNAL(finishedLoading()), this, SLOT(reenableWidget()));
+        connect(d->collectionModel, &Zotero::CollectionModel::modelReset, this, &ZoteroBrowser::modelReset);
+        connect(d->tagModel, &Zotero::TagModel::modelReset, this, &ZoteroBrowser::modelReset);
+        connect(d->items, &Zotero::Items::foundElement, this, &ZoteroBrowser::showItem);
+        connect(d->items, &Zotero::Items::stoppedSearch, this, &ZoteroBrowser::reenableWidget);
+        connect(d->tags, &Zotero::Tags::finishedLoading, this, &ZoteroBrowser::reenableWidget);
 
         d->needToApplyCredentials = false;
 
@@ -363,14 +345,14 @@ void ZoteroBrowser::retrieveGroupList() {
         d->comboBoxGroupList->clear();
         d->comboBoxGroupListInitialized = false;
 
-        disconnect(d->groups, SIGNAL(finishedLoading()), this, SLOT(gotGroupList()));
+        disconnect(d->groups, &Zotero::Groups::finishedLoading, this, &ZoteroBrowser::gotGroupList);
         d->groups->deleteLater();
         d->api.clear();
 
         d->api = QSharedPointer<Zotero::API>(new Zotero::API(Zotero::API::UserRequest, userId, d->lineEditApiKey->text(), this));
         d->groups = new Zotero::Groups(d->api, this);
 
-        connect(d->groups, SIGNAL(finishedLoading()), this, SLOT(gotGroupList()));
+        connect(d->groups, &Zotero::Groups::finishedLoading, this, &ZoteroBrowser::gotGroupList);
     }
 }
 
@@ -398,7 +380,6 @@ void ZoteroBrowser::gotGroupList() {
     reenableWidget();
 }
 
-#ifdef HAVE_QTOAUTH // krazy:exclude=cpp
 void ZoteroBrowser::getOAuthCredentials()
 {
     QPointer<Zotero::OAuthWizard> wizard = new Zotero::OAuthWizard(this);
@@ -411,26 +392,10 @@ void ZoteroBrowser::getOAuthCredentials()
     }
     delete wizard;
 }
-#else // HAVE_QTOAUTH
-void ZoteroBrowser::applyManuallyEnteredCredentials()
-{
-    bool userIdOk = false;
-    const int userId = d->lineEditNumericUserId->text().toInt(&userIdOk);
-    const QString apiKey = d->lineEditApiKey->text();
-    static const QRegExp apiKeyRegExp(QLatin1String("[a-zA-Z0-9]{24}$"));
-    if (userIdOk && userId > 0 && !apiKey.isEmpty() && apiKeyRegExp.indexIn(apiKey) == 0) {
-        d->queueWriteOAuthCredentials();
-        updateButtons();
-        retrieveGroupList();
-    } else
-        KMessageBox::error(this, i18n("<qt>The provided Zotero credentials are incomplete:<ul><li>The numeric user id must be a positive number.</li><li>The API key must be a string of 24 alpha-numeric characters.<br/>It is not your Zotero password.</li></ul></qt>"), i18n("Incomplete Zotero credentials"));
-}
-
-#endif // HAVE_QTOAUTH
 
 void ZoteroBrowser::readOAuthCredentials(bool ok) {
     /// Do not call this slot a second time
-    disconnect(d->wallet, SIGNAL(walletOpened(bool)), this, SLOT(readOAuthCredentials(bool)));
+    disconnect(d->wallet, &Wallet::walletOpened, this, &ZoteroBrowser::readOAuthCredentials);
 
     if (ok && (d->wallet->hasFolder(ZoteroBrowser::Private::walletFolderOAuth) || d->wallet->createFolder(ZoteroBrowser::Private::walletFolderOAuth)) && d->wallet->setFolder(ZoteroBrowser::Private::walletFolderOAuth)) {
         if (d->wallet->hasEntry(ZoteroBrowser::Private::walletEntryKBibTeXZotero)) {
@@ -448,21 +413,21 @@ void ZoteroBrowser::readOAuthCredentials(bool ok) {
         } else
             qDebug() << "No Zotero credentials stored in KWallet";
     } else
-        kWarning() << "Accessing KWallet to sync API key did not succeed";
+        qWarning() << "Accessing KWallet to sync API key did not succeed";
     reenableWidget();
 }
 
 void ZoteroBrowser::writeOAuthCredentials(bool ok) {
-    disconnect(d->wallet, SIGNAL(walletOpened(bool)), this, SLOT(writeOAuthCredentials(bool)));
+    disconnect(d->wallet, &Wallet::walletOpened, this, &ZoteroBrowser::writeOAuthCredentials);
 
     if (ok && (d->wallet->hasFolder(ZoteroBrowser::Private::walletFolderOAuth) || d->wallet->createFolder(ZoteroBrowser::Private::walletFolderOAuth)) && d->wallet->setFolder(ZoteroBrowser::Private::walletFolderOAuth)) {
         QMap<QString, QString> map;
         map.insert(ZoteroBrowser::Private::walletKeyZoteroId, d->lineEditNumericUserId->text());
         map.insert(ZoteroBrowser::Private::walletKeyZoteroApiKey, d->lineEditApiKey->text());
         if (d->wallet->writeMap(ZoteroBrowser::Private::walletEntryKBibTeXZotero, map) != 0)
-            kWarning() << "Writing API key to KWallet failed";
+            qWarning() << "Writing API key to KWallet failed";
     } else
-        kWarning() << "Accessing KWallet to sync API key did not succeed";
+        qWarning() << "Accessing KWallet to sync API key did not succeed";
     reenableWidget();
 }
 
